@@ -1,4 +1,10 @@
-use std::num::{Zero, One};
+#[derive(Clone, Copy, Default, Debug)]
+#[repr(C, align(2))]
+pub struct f16_stub(pub u16);
+
+#[derive(Clone, Copy, Default, Debug)]
+#[repr(C, align(4))]
+pub struct f16x2_stub(pub u16, pub u16);
 
 pub trait FloatStub: Sized {
   type Inner;
@@ -6,9 +12,6 @@ pub trait FloatStub: Sized {
   fn from_parts(negative: bool, exponent: Self::Inner, fraction: Self::Inner) -> Self;
 }
 
-#[derive(Clone, Copy, Default, Debug)]
-pub struct f16_stub(u16);
-
 impl FloatStub for f16_stub {
   type Inner = u16;
 
@@ -21,16 +24,14 @@ impl FloatStub for f16_stub {
   }
 }
 
-impl Zero for f16_stub {
+impl f16_stub {
   #[inline]
-  fn zero() -> f16_stub {
+  fn _zero() -> f16_stub {
     f16_stub(0)
   }
-}
 
-impl One for f16_stub {
   #[inline]
-  fn one() -> f16_stub {
+  fn _one() -> f16_stub {
     f16_stub::from_parts(false, 0, 0)
   }
 }
